@@ -138,6 +138,24 @@ def test_same_hash_when_content_the_same_but_underlying_vector_size_differs():
     assert hash(x) == hash(y)
 
 
+class HashabilityControlled(object):
+
+    hashable = True
+
+    def __hash__(self):
+        if self.hashable:
+            return 4 # Proven random
+        raise ValueError("I am not currently hashable.")
+
+
+def test_map_does_not_hash_values_on_second_hash_invocation():
+    hashable = HashabilityControlled()
+    x = pmap(dict(el=hashable))
+    hash(x)
+    hashable.hashable = False
+    hash(x)
+
+
 def test_update_with_multiple_arguments():
     # If same value is present in multiple sources, the rightmost is used.
     x = m(a=1, b=2, c=3)    
@@ -400,4 +418,4 @@ def test_pmap_unorderable():
 
 def test_supports_weakref():
     import weakref
-    weakref.ref(m(a=1))
\ No newline at end of file
+    weakref.ref(m(a=1))
