@@ -1,7 +1,6 @@
-import six
-
 from pyrsistent import pset, s
 import pytest
+import pickle
 
 
 def test_literalish_works():
@@ -117,7 +116,7 @@ def test_evolver_simple_add():
     e.add(4)
     assert e.is_dirty()
 
-    x2 = e.pset()
+    x2 = e.persistent()
     assert not e.is_dirty()
     assert x2 == s(1, 2, 3, 4)
     assert x == s(1, 2, 3)
@@ -127,7 +126,7 @@ def test_evolver_simple_remove():
     e = x.evolver()
     e.remove(2)
 
-    x2 = e.pset()
+    x2 = e.persistent()
     assert x2 == s(1, 3)
     assert x == s(1, 2, 3)
 
@@ -135,10 +134,37 @@ def test_evolver_simple_remove():
 def test_evolver_no_update_produces_same_pset():
     x = s(1, 2, 3)
     e = x.evolver()
-    assert e.pset() is x
+    assert e.persistent() is x
 
 
 def test_evolver_len():
     x = s(1, 2, 3)
     e = x.evolver()
     assert len(e) == 3
+
+
+def test_copy_returns_reference_to_self():
+    s1 = s(10)
+    assert s1.copy() is s1
+
+
+def test_pickling_empty_set():
+    assert pickle.loads(pickle.dumps(s(), -1)) == s()
+
+
+def test_pickling_non_empty_map():
+    assert pickle.loads(pickle.dumps(s(1, 2), -1)) == s(1, 2)
+
+
+def test_supports_weakref():
+    import weakref
+    weakref.ref(s(1))
+
+
+def test_update():
+    assert s(1, 2, 3).update([3, 4, 4, 5]) == s(1, 2, 3, 4, 5)
+
+
+def test_update_no_elements():
+    s1 = s(1, 2)
+    assert s1.update([]) is s1
